<?php

declare(strict_types=1);

namespace Drupal\layout_builder_browser_library\Controller;

use Drupal\Core\Url;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\layout_builder_browser\Controller\BrowserController as BrowserControllerBase;
use Drupal\layout_builder_browser\Entity\LayoutBuilderBrowserBlock;

/**
 * Controller class responsible for managing browser functionality.
 */
class BrowserController extends BrowserControllerBase {

  /**
   * {@inheritdoc}
   */
  protected function getBlocks(SectionStorageInterface $section_storage, $delta, $region, array $blocks): array {
    $links = [];

    foreach ($blocks as $block_id => $block) {
      if (!isset($block['layout_builder_browser_data']) || !$block['layout_builder_browser_data'] instanceof LayoutBuilderBrowserBlock) {
        continue;
      }
      $layoutBuilderBlock = $block['layout_builder_browser_data'];

      $block_render_array = [];
      if (\trim($layoutBuilderBlock->image_path) != '') {
        $block_render_array['image'] = [
          '#theme' => 'image',
          '#uri' => $layoutBuilderBlock->image_path,
          '#alt' => $layoutBuilderBlock->image_alt,
        ];
      }
      $block_render_array['label'] = ['#markup' => $layoutBuilderBlock->label()];
      $attributes = $this->getAjaxAttributes();
      $attributes['class'][] = 'js-layout-builder-block-link';
      $link = [
        '#type' => 'link',
        '#title' => $block_render_array,
        '#url' => Url::fromRoute(
          'layout_builder.add_block',
          [
            'section_storage_type' => $section_storage->getStorageType(),
            'section_storage' => $section_storage->getStorageId(),
            'delta' => $delta,
            'region' => $region,
            'plugin_id' => $block_id,
          ]
        ),
        '#attributes' => $attributes,
      ];

      $blockRender = [
        '#type' => 'container',
        '#attributes' => [
          'class' => [
            'layout-builder-browser-block-item',
          ],
        ],
        'link' => $link,
      ];

      // Tooltip.
      $settings = $layoutBuilderBlock->getThirdPartySettings('layout_builder_browser_library');
      if (isset($settings['library_image_path']) && \trim($settings['library_image_path']) != '') {
        $tooltip_link = $link;
        $tooltip_link['#title'] = [
          '#theme' => 'image',
          '#uri' => $settings['library_image_path'],
          '#alt' => $settings['library_image_alt'] ?? '',
        ];
        $blockRender['tooltip'] = [
          '#type' => 'container',
          '#attributes' => [
            'class' => ['lb-tooltip'],
          ],
          'image' => $tooltip_link,
          '#attached' => [
            'library' => [
              'layout_builder_browser_library/tooltip',
            ],
          ],
        ];
      }

      $links[] = $blockRender;
    }
    return $links;
  }

}
